# SessyPy
A python wrapper for Sessy's local REST api.

[![PyPI Build & Publish](https://github.com/PimDoos/sessypy/actions/workflows/python-publish.yml/badge.svg)](https://github.com/PimDoos/sessypy/actions/workflows/python-publish.yml)
[![Python package](https://github.com/PimDoos/sessypy/actions/workflows/python-package.yml/badge.svg)](https://github.com/PimDoos/sessypy/actions/workflows/python-package.yml)

Installation
============

Automatic installation
----------------------
Install the package via PyPI:
```
pip install sessypy
```

Manual installation
-------------------
```
git clone https://github.com/PimDoos/sessypy
pip install ./sessypy
```
